@@ -226,8 +226,8 @@ def viperhpdeoptimize(vipertoken,host,port,consumefrom,produceto,companyname,con
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
-def viperhpdetraining(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,partition=-1,modelruns=50,
-                      hpdeport=-999,offset=-1,islogistic=0,
+def viperhpdetraining(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,viperconfigfile,
+                      partition=-1,modelruns=50,hpdeport=-999,offset=-1,islogistic=0,
                       brokerhost='',brokerport=9092,timeout=120,microserviceid=''):
 
     #reads the fieldnames and gets latest data from each stream (or fieldname)
@@ -238,7 +238,7 @@ def viperhpdetraining(vipertoken,host,port,consumefrom,produceto,companyname,con
         
     value=("viperhpdetraining?vipertoken="+vipertoken + "&consumefrom="+consumefrom + "&produceto=" + produceto + "&consumerid="+consumerid +
            "&producerid="+producerid + "&companyname="+companyname + "&partition="+str(partition)+"&modelruns="+str(modelruns) +"&hpdehost=" +hpdehost +
-           "&hpdeport="+str(hpdeport)+"&brokerhost="+brokerhost+ "&offset="+str(offset) +
+           "&hpdeport="+str(hpdeport)+"&brokerhost="+brokerhost+ "&offset="+str(offset) + "&viperconfigfile="+viperconfigfile +
            "&brokerport="+str(brokerport))
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
